# Articolare Python Client

Articolare is a Python client for the Articolare API. It is designed to facilitate interactions with the API, providing a simple and intuitive interface for creating and managing requests.

# Installation
To install the Articolare Python client, you can use pip:
* Copy code 
```
  pip install articolare
```

# Usage
First, you need to initialize the ArticolareClient with your API key:
```
from articolare import create
```
```
  client = create.ArticolareClient(api_key="your-api-key"))
```

# Create
You can then use the create method to make a request to the API:
* languages available:
  * English
  * Portuguese
  * Spanish
  * Italian
* Tokens:
  * Max Tokens = 1000 - If you require more tokens, please refer to our documentation on https://www.articolare.com/
```
response = client.create(
    model="art-translator",
    lang="english",
    style="conversation",
    dialect="european"
    prompt="Enter your prompt here",
    max_tokens=1000
)
```

* The create method returns a dictionary containing the response data from the API.

# Testing
This library includes a basic test suite, which you can run using pytest:
* pytest
```
pytest
```

# License
The Articolare library is owned and managed by Articolare ltd. 

